@@ -6,7 +6,6 @@ $VERSION = "0.499"; # created before Text::PDF::API version 0.5 (final)
 use vars qw(@ISA);
 @ISA = qw(Text::PDF::Dict);
 
-use POSIX;
 use Text::PDF::Utils;
 use Compress::Zlib;
 
@@ -107,30 +106,26 @@ sub resolveFontFile {
 sub readAFM {
 	my ($self,$file)=@_;
 	$self->{' AFM'}={};
-	if(! -e $file) {die "file='$file' not existant.";}
-	open(AFMF, $file) or die "Can't find the AFM file for $file";
+	open(AFM, $file) or die "Can't find the AFM file for $file";
 	local($/, $_) = ("\n", undef);  # ensure correct $INPUT_RECORD_SEPARATOR
-	while ($_=<AFMF>) {
+	while (<AFM>) {
 		next if /^StartKernData/ .. /^EndKernData/;  # kern data not parsed yet
 		next if /^StartComposites/ .. /^EndComposites/; # same for composites
 		if (/^StartCharMetrics/ .. /^EndCharMetrics/) {
 		# only lines that start with "C" or "CH" are parsed
-			next unless $_=~/^CH?\s/;
-			my($ch)   = $_=~/^CH?\s+(\d+)\s*;/;
-			$ch=$ch||0;
-			my($name) = $_=~/\bN\s+(\.?\w+)\s*;/;
-			my($wx)   = $_=~/\bWX\s+(\d+)\s*;/;
-			my($bbox)    = $_=~/\bB\s+([^;]+);/;
+			next unless /^CH?\s/;
+			my($ch)   = /^CH?\s+(\d+)\s*;/;
+			my($name) = /\bN\s+(\.?\w+)\s*;/;
+			my($wx)   = /\bWX\s+(\d+)\s*;/;
+			my($bbox)    = /\bB\s+([^;]+);/;
 			$bbox =~ s/\s+$//;
 			# Should also parse lingature data (format: L successor lignature)
-			$self->{' AFM'}->{'wx'}{$name} = $wx ;
-			$self->{' AFM'}->{'bbox'}{$name} = $bbox ;
-			if($ch>0) {
-				$self->{' AFM'}->{'char'}[$ch]=$name ;
-			} 
+			$self->{' AFM'}->{'wx'}{$name} = $wx;
+			$self->{' AFM'}->{'bbox'}{$name} = $bbox;
+			$self->{' AFM'}->{'char'}[$ch]=$name if($ch>0); 
 			next;
 		}
-		last if $_=~/^EndFontMetrics/;
+		last if /^EndFontMetrics/;
 		if (/(^\w+)\s+(.*)/) {
 			my($key,$val) = ($1, $2);
 			$key = lc $key;
@@ -144,7 +139,7 @@ sub readAFM {
            		print STDERR "Can't parse: $_";
 		}
 	}
-	close(AFMF);
+	close(AFM);
 	unless (exists $self->{' AFM'}->{wx}->{'.notdef'}) {
 		$self->{' AFM'}->{wx}->{'.notdef'} = 0;
 		$self->{' AFM'}->{bbox}{'.notdef'} = "0 0 0 0";
@@ -290,7 +285,8 @@ sub readPSF {
 	#xheight 
 	# get ury from x or bbx/2 and adjust per delta blue
 	($llx,$lly,$urx,$ury)=split(/\s+/,$h{'bbx'}{'x'});
-	$l=$ury||POSIX::ceil($bbx[3]/2);
+	use Posix;
+	$l=$ury||Posix::ceil($bbx[3]/2);
 	$delta=10000;
 	foreach my $b (@blue_val) {
 		if($delta>abs($b-$l)){
@@ -311,7 +307,6 @@ sub readPSF {
 sub parsePS {
 	my ($self,$file,$noFM)=@_;
 	my ($l,$l1,$l2,$l3,$stream,@lines,$line,$head,$body,$tail);
-	if(! -e $file) {die "file='$file' not existant.";}
 	$l=-s $file;
 	open(INF,$file);
 	binmode(INF);
@@ -342,7 +337,7 @@ sub parsePS {
 		@lines=<INF>;
 		close(INF);
 		$stream=join('',@lines);
-	} elsif($line eq '%!') {
+	} elsif($line EQ '%!') {
 		seek(INF,0,0);
 		while($line=<INF>) {
 			if(!$l1) {
@@ -385,27 +380,27 @@ sub parsePS {
 }
 
 sub encodeProper {
-	my ($self, $encoding, $first,$last, @glyphs) = @_;
+	my ($self, $encoding, @glyphs) = @_;
 	my (@w);
 
 	if($encoding) {
 		$self->{'Encoding'}=PDFDict();
 		$self->{'Encoding'}->{'Type'}=PDFName('Encoding');
-		if( $encoding eq 'MacRomanEncoding' ) {
+		if( $encoding EQ 'MacRomanEncoding' ) {
 			@{$self->{' AFM'}->{'char'}}=@mac_enc;
-		} elsif( $encoding eq 'WinAnsiEncoding' ) {
+		} elsif( $encoding EQ 'WinAnsiEncoding' ) {
 			@{$self->{' AFM'}->{'char'}}=@win_enc;
 		} elsif( $encoding=~/StandardEncoding$/ ) {
 			$encoding='WinAnsiEncoding';
 			@{$self->{' AFM'}->{'char'}}=@std_enc;
-		} elsif( lc($encoding) eq 'latin1' ) {
+		} elsif( lc($encoding) EQ 'latin1' ) {
 			$encoding='WinAnsiEncoding';
 			@{$self->{' AFM'}->{'char'}}=@latin1_enc;
 			@glyphs = @latin1_enc;
-		} elsif( lc($encoding) eq 'custom' ) {
+		} elsif( lc($encoding) EQ 'custom' ) {
 			$encoding='WinAnsiEncoding';
 			@{$self->{' AFM'}->{'char'}}=@glyphs;
-		} elsif( lc($encoding) eq 'asis' ) {
+		} elsif( lc($encoding) EQ 'asis' ) {
 			undef($encoding);
 		} else {
 			$encoding='WinAnsiEncoding';
@@ -415,8 +410,8 @@ sub encodeProper {
 		my $notdefbefore=1;
 		@w=();
 		if(@glyphs){
-			foreach my $w ($first..$last) {
-				if($glyphs[$w] eq '.notdef') {
+			foreach my $w (0..255){
+				if($glyphs[$w] EQ '.notdef') {
 					$notdefbefore=1;
 					next;
 				} else {
@@ -430,11 +425,7 @@ sub encodeProper {
 			$self->{'Encoding'}->{'Differences'}=PDFArray(@w);
 		}
 	}
-	@w = map { 
-		PDFNum($self->{' AFM'}->{'wx'}{$_ || '.notdef'} || 0) 
-	} map {
-		$self->{' AFM'}->{'char'}[$_]	
-	} ($first..$last);
+	@w = map { PDFNum($self->{' AFM'}->{'wx'}{$_} || 0) } @{$self->{' AFM'}->{'char'}};
 	$self->{'Widths'}=PDFArray(@w);
 
 }
@@ -449,33 +440,31 @@ sub newNonEmbed {
 	$self->{'Type'} = PDFName("Font");
 	$self->{'Subtype'} = PDFName("Type1");
 	$self->{'BaseFont'} = PDFName($self->{' AFM'}->{'fontname'});
-	$self->{'FirstChar'} = PDFNum(32);
-	$self->{'LastChar'} = PDFNum(255);
+	$self->{'FirstChar'} = PDFNum('0');
+	$self->{'LastChar'} = PDFNum('255');
 	$self->{'Name'} = PDFName($pdfname);
 
-	$self->encodeProper($encoding, 32, 255, @glyphs);
+	$self->encodeProper($encoding, @glyphs);
 	
 	$self->{'FontDescriptor'}=PDFDict();
 	$self->{'FontDescriptor'}->{'Type'}=PDFName('FontDescriptor');
 	$self->{'FontDescriptor'}->{'FontName'}=PDFName($self->{' AFM'}->{'fontname'});
 	$self->{'FontDescriptor'}->{'Ascent'}=PDFNum($self->{' AFM'}->{'ascender'}||0);
 	$self->{'FontDescriptor'}->{'Descent'}=PDFNum($self->{' AFM'}->{'descender'}||0);
+	$self->{'FontDescriptor'}->{'CapHeight'}=PDFNum($self->{' AFM'}->{'capheight'});
 	$self->{'FontDescriptor'}->{'ItalicAngle'}=PDFNum($self->{' AFM'}->{'italicangle'}||0);
 	@w = map { PDFNum($_ || 0) } split(/\s+/,$self->{' AFM'}->{'fontbbox'});
-	$self->{'FontDescriptor'}->{'CapHeight'}=PDFNum($self->{' AFM'}->{'capheight'}||$w[3]->val||0);
 	$self->{'FontDescriptor'}->{'FontBBox'}=PDFArray(@w);
 	$self->{'FontDescriptor'}->{'StemV'}=PDFNum(0);
 	$self->{'FontDescriptor'}->{'StemH'}=PDFNum(0);
-	$self->{'FontDescriptor'}->{'XHeight'}=PDFNum($self->{' AFM'}->{'xheight'}||$w[3]->val||0);
+	$self->{'FontDescriptor'}->{'XHeight'}=PDFNum($self->{' AFM'}->{'xheight'});
 	
 	my $flags=0;
-	$self->{' AFM'}->{'encoding'}=$self->{' AFM'}->{'encoding'}||'';
-	$flags|=1 if(lc($self->{' AFM'}->{'isfixedpitch'}) ne 'false');
+	$flags|=1 if(lc($self->{' AFM'}->{'isfixedpitch'}) NE 'false');
 	if($self->{' AFM'}->{'encoding'}=~/standardencoding/cgi){
-		$flags|=1<<5 ;
-	} else {
 		$flags|=1<<2 ;
-		$flags|=1<<3 ;
+	} else {
+		$flags|=1<<5 ;
 	}
 	$flags|=1<<6 if(!$self->{' AFM'}->{'italicangle'});
 	$flags|=1<<17 if($self->{' AFM'}->{'fontname'}=~/SC$/);
@@ -493,7 +482,6 @@ sub newCore {
 	my ($file);
 	
 	$file=resolveFontFile("$name.afm");
-	if(! -e $file) {die "file='$file' (was '$name.afm') not existant.";}
 
 	$self=newNonEmbed($class, $parent, $file, $pdfname, $encoding, @glyphs);
 
@@ -504,27 +492,23 @@ sub new {
 	my ($class, $parent, $file1, $file2, $pdfname, $encoding, @glyphs) = @_;
 	my (@w);
 	my ($l1,$l2,$l3,$stream);
-	if($file1) {
-		if($file2) {
-			$self=newNonEmbed($class, $parent, $file2, $pdfname, $encoding, @glyphs);
-			($l1,$l2,$l3,$stream)=$self->parsePS($file1,0);
-		} else {
-			$self=$class->SUPER::new();
-			($l1,$l2,$l3,$stream)=$self->parsePS($file1,1);
-			$self->newNonEmbed($parent, $file2, $pdfname, $encoding, @glyphs);
-		}
-		my $s = PDFDict();
-		$self->{'FontDescriptor'}->{'FontFile'} = $s;
-		$s->{'Length1'} = PDFNum($l1);
-		$s->{'Length2'} = PDFNum($l2);
-		$s->{'Length3'} = PDFNum($l3);
-		$s->{'Filter'} = PDFArray(PDFName("FlateDecode"));
-		$s->{' stream'} = $stream;
-		$parent->new_obj($s);
-	} else {
+	if($file2) {
 		$self=newNonEmbed($class, $parent, $file2, $pdfname, $encoding, @glyphs);
+		($l1,$l2,$l3,$stream)=$self->parsePS($file1,0);
+	} else {
+		$self=$class->SUPER::new();
+		($l1,$l2,$l3,$stream)=$self->parsePS($file1,1);
+		$self->newNonEmbed($parent, $file2, $pdfname, $encoding, @glyphs);
 	}
 	
+	my $s = PDFDict();
+	$self->{'FontDescriptor'}->{'FontFile'} = $s;
+	$s->{'Length1'} = PDFNum($l1);
+	$s->{'Length2'} = PDFNum($l2);
+	$s->{'Length3'} = PDFNum($l3);
+	$s->{'Filter'} = PDFArray(PDFName("FlateDecode"));
+	$s->{' stream'} = $stream;
+	$parent->new_obj($s);
 	$parent->new_obj($self->{'FontDescriptor'});
 	return($self);
 }
@@ -549,11 +533,11 @@ sub reencode {
 	$self->{'Type'} = PDFName("Font");
 	$self->{'Subtype'} = PDFName("Type1");
 	$self->{'BaseFont'} = PDFName($class->{' AFM'}->{'fontname'});
-	$self->{'FirstChar'} = PDFNum(32);
-	$self->{'LastChar'} = PDFNum(255);
+	$self->{'FirstChar'} = PDFNum('0');
+	$self->{'LastChar'} = PDFNum('255');
 	$self->{'Name'} = PDFName($pdfname);
 	
-	$self->encodeProper($encoding,32,255, @glyphs);
+	$self->encodeProper($encoding, @glyphs);
 		
 	$self->{'FontDescriptor'}=$class->{'FontDescriptor'};
 	$parent->new_obj($self);
